#!/bin/sh 
#
# *******************************************************************************************
#
#  Copyright (c) 2000, Jean Chouanard <chouanard@parc.xerox.com>, Xerox - PARC
#      All rights reserved.
#
# *******************************************************************************************
#
OS=`uname -r`
Pwd=/usr/bin/pwd
umask 077
ARCH=`uname -p`

echo "YASSP v0 Beta#15"
echo ""
#
# Thanks to "Bob Kong" <rkong@att.com>
# for the applhome finding functions
#

DirName() {
        expr ${1}'/' : '\(/\)[^/]*/$' \
                \| ${1}'/' : '\(.*\)//*[^/]' \
                \| .
}

BaseName() {
        expr //$1 : ".*/\(.*\)$2" \| //$1 : ".*/\(.*\)"
}

SetApplHome() {
        [ -h $0 ] && {
                _link=`expr "\`ls -l ${0}\`" : '.*> \(.*\)'`
                _link=`DirName "$_link"`
        }
        if [ `expr "${_link}" : "^/"` -ne 1 ]; then
                _dir=`cd \`DirName ${0}\`/$_link 2>&1; [ $? -eq 0 ] && $Pwd`
        else
                _dir=`cd $_link 2>&1; [ $? -eq 0 ] && $Pwd`
        fi
        [ $? -ne 0 ] && {
                ${ECHO} "ERROR: unable to determine parent directory - = $0"
                exit 0
        }
	APPLHOME=$_dir
#       APPLHOME=`DirName \`expr $_dir : '^/tmp_mnt\(.*\)$' \| = $_dir\``
}

SetApplHome
#
#
cd ${APPLHOME}
if [ ! \( ${ARCH} = "sparc" -o ${ARCH} = "i386" \) ] ; then
    echo "Sorry, only for sparc and i386 architecture :-)"
    exit
fi
SSH=NO
if [ "X${PKGLIST}" = "X" ] ; then
    echo "Are you ready to install YASSP? It will modify lot of system resources..."
    echo "and will prevent some non-essential services from running on your system."
    echo "Do you really want to install YASSP? [y|n] (n) \c"
    read RE
    if [ ! "X${RE}" = "Xy" ] ; then
	echo "See you next time."
	exit
    fi
    echo "\n\nNote: "
    echo "      you can always overwrite YASSP package choices by setting up"
    echo "      the environment variable PKGLIST before running YASSP to the"
    echo "      list of packages you want to install."
    echo "      If PKGLIST is defined, yassp's install won't ask you to choose"
    echo "      which package you want to install."
    echo

    PKGLIST="SECclean GNUrcs GNUgzip PARCdaily WVtcpd PRFtripw "
    echo "\n\nBy default, YASSP will install the following packages: "
    echo "  SECclean  : The core package, securing your Solaris installation."
    echo "  GNUrcs    : RCS 5.7 and diff 2.7 [GNU]"
    echo "  GNUgzip   : gzip 1.2.4a [GNU]"
    echo "  PARCdaily : Some daily script, loggs rotation, backup and RCS for systems files... Need GNUgzip and GNUrcs"
    echo "  WVtcpd    : tcp_wrappers 7.6 + rpcbind 2.1 [Wietse Venema]"
    echo "  PRFtripw  : Tripwire 1.2 [Purdue Research Foundation of Purdue University]"
#    echo "  AUBtocsin : tocsin network scan detector 2.1 [Auburn Univ. Engineering]" 
if [ "$OS" = "5.8" ] ; then 
    PKGLIST="${PKGLIST} OPENssh"
    echo "  OPENssh   : OpenSSH 2.3.0p1 [OpenSSH.com]"
fi
    echo "\nType the package list you want to install or hit return to accept the default: \n ${PKGLIST}"
    read PKGTMP
    if [ "X${PKGTMP}" != "X" ] ; then
	for i in $PKGTMP
	do
	    if [ $i = "OPENssh" ] ; then
		SSH="YES"
		if [ "$OS" != "5.8" ] ; then 
		    echo "OpenSSH not supported on $OS"
		    exit
		fi
	    fi
	    if [ ! -f `echo $i | tr '[:upper:]' '[:lower:]'`_${ARCH} ] ; then
		echo "$i is not a valid package name"
		exit
	    fi
	done
	PKGLIST="${PKGTMP}"
    fi
fi     
echo "YASSP will install: ${PKGLIST}"
trap ""  2 3
echo

echo "\n\nInstalling the various package: \n"

#
# removing the windex so that tcpd and tripwire
# installation don't try to rebuild it.
#
rm -f /usr/share/man/windex

#
# Install the chosen packages
#
umask 022
for i in ${PKGLIST}
do
    PKGFI=`echo $i | tr '[:upper:]' '[:lower:]'`
    echo
    echo "=========="
    echo "$i"
    echo "=========="
    echo
    /usr/sbin/pkgadd -n -a ./admin -d ${PKGFI}_${ARCH} $i
    if [ $? -ne 0 ] ; then
	echo "*** Installation of $i failled"
	exit
    fi
done
echo "Rebuilding the whatis database"
/usr/lib/makewhatis /usr/man; 
/usr/lib/makewhatis /usr/openwin/man;
/usr/lib/makewhatis /opt/local/man; 
echo "YASSP is installed."
echo "Most of these changes will take action at the next reboot."
echo ""
echo "**** YOUR WORK IS NOT DONE YET ****"
echo "     *) Edit and configure /etc/yassp.conf"
echo "     *) Edit and configure /etc/hosts.deny /etc/hosts.allow"
if [ "X${SSH}" = "XYES" ] ; then
    echo "     *) Edit and configure /etc/sshd_config /etc/ssh_config"
fi
echo "     *) Read http://www.yassp.org/after.html"
echo "        and the papers linked under http://www.yassp.org/ref.html"
echo "     *) make any additional changes/software installation"
echo ""
echo "     *) CREATE YOUR tripwire DATABASE AND SAVE IT!!!"
echo ""

echo " Type:\nvi /etc/yassp.conf /etc/hosts.deny /etc/hosts.allow \c"
if [ "X${SSH}" = "XYES" ] ; then
    echo "/etc/sshd_config /etc/ssh_config \c"
fi
MACH=`/sbin/uname -n`
echo "; cd /secure/tripwire; ./tripwire -i 2 -initialise -c tw.config; cp /secure/tripwire/databases/tw.db_${MACH} TO_A_SECURE_PLACE"
echo ""
echo ""
echo "   ***YOUR feedback*** is important: please send comments or flame to: "
echo "            sansro@sans.org, chouanard@parc.xerox.com"
echo "            with \"YASSP\" in the subject"
echo ""


